Documentation
¶
Overview ¶
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
templ: version: v0.3.1001
Index ¶
- func AddonDetail(nav []NavItem, addon AddonRow, streamURL string, assetBase string) templ.Component
- func Addons(nav []NavItem, rows []AddonRow, assetBase string) templ.Component
- func Config(nav []NavItem, envVars []EnvVarRow, runtime RuntimeInfo, ...) templ.Component
- func Layout(title string, nav []NavItem, assetBase string) templ.Component
- func Logs(nav []NavItem, rows []LogRow, streamURL string, assetBase string) templ.Component
- func Requests(nav []NavItem, rows []RequestRow, assetBase string) templ.Component
- func Routes(nav []NavItem, rows []RouteRow, assetBase string) templ.Component
- type AddonEventRow
- type AddonRow
- type ConfigAddonRow
- type EnvVarRow
- type LogRow
- type NavItem
- type RequestRow
- type RouteRow
- type RuntimeInfo
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddonDetail ¶ added in v1.4.0
func Config ¶ added in v1.5.0
func Config(nav []NavItem, envVars []EnvVarRow, runtime RuntimeInfo, addons []ConfigAddonRow, assetBase string) templ.Component
Types ¶
type AddonEventRow ¶ added in v1.4.0
type AddonEventRow struct {
Label string
Level string
Detail map[string]string // flattened for display
}
AddonEventRow is the view model for a single addon panel event.
type AddonRow ¶
type AddonRow struct {
ID string
Label string
Capabilities []string
Resources []string
DetailURL string // link to the addon's event stream detail page
}
AddonRow is the view model for a registered addon in the panel.
type ConfigAddonRow ¶ added in v1.5.0
ConfigAddonRow is the view model for an addon in the config page.
type EnvVarRow ¶ added in v1.5.0
type EnvVarRow struct {
Key string
Value string // redacted if secret
Source string
Required bool
Secret bool
Description string
}
EnvVarRow is the view model for a single env var in the config page.
type RequestRow ¶
type RequestRow struct {
ID string
Timestamp time.Time
Method string
Path string
Status int
LatencyMS float64
RequestID string
}
RequestRow is the view model for a single request entry.
Click to show internal directories.
Click to hide internal directories.